Class: Google::Apis::FirebasedataconnectV1beta::GenerateQueryResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1beta::GenerateQueryResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb
Overview
Output for streaming generate query requests
Instance Attribute Summary collapse
-
#part ⇒ Google::Apis::FirebasedataconnectV1beta::Part
Represents a chunk of content.
-
#status ⇒ Google::Apis::FirebasedataconnectV1beta::GenerationStatus
Represents the progress of the server side generation request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateQueryResponse
constructor
A new instance of GenerateQueryResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateQueryResponse
Returns a new instance of GenerateQueryResponse.
481 482 483 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 481 def initialize(**args) update!(**args) end |
Instance Attribute Details
#part ⇒ Google::Apis::FirebasedataconnectV1beta::Part
Represents a chunk of content.
Corresponds to the JSON property part
474 475 476 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 474 def part @part end |
#status ⇒ Google::Apis::FirebasedataconnectV1beta::GenerationStatus
Represents the progress of the server side generation request.
Corresponds to the JSON property status
479 480 481 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 479 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
486 487 488 489 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 486 def update!(**args) @part = args[:part] if args.key?(:part) @status = args[:status] if args.key?(:status) end |