Class: Google::Apis::FirebasedataconnectV1beta::GenerateSchemaResponse
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1beta::GenerateSchemaResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb
Overview
Output for streaming generate schema requests
Instance Attribute Summary collapse
-
#part ⇒ Google::Apis::FirebasedataconnectV1beta::Part
Represents a chunk of content.
-
#status ⇒ Google::Apis::FirebasedataconnectV1beta::GenerationStatus
Represents the progress of the server side generation request.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenerateSchemaResponse
constructor
A new instance of GenerateSchemaResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenerateSchemaResponse
Returns a new instance of GenerateSchemaResponse.
521 522 523 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 521 def initialize(**args) update!(**args) end |
Instance Attribute Details
#part ⇒ Google::Apis::FirebasedataconnectV1beta::Part
Represents a chunk of content.
Corresponds to the JSON property part
514 515 516 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 514 def part @part end |
#status ⇒ Google::Apis::FirebasedataconnectV1beta::GenerationStatus
Represents the progress of the server side generation request.
Corresponds to the JSON property status
519 520 521 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 519 def status @status end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
526 527 528 529 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 526 def update!(**args) @part = args[:part] if args.key?(:part) @status = args[:status] if args.key?(:status) end |