Class: Google::Apis::FirebasedataconnectV1beta::GraphqlErrorExtensions
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1beta::GraphqlErrorExtensions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb
Overview
GraphqlErrorExtensions contains additional information of GraphqlError.
Instance Attribute Summary collapse
-
#code ⇒ String
Maps to canonical gRPC codes.
-
#debug_details ⇒ String
More detailed error message to assist debugging.
-
#file ⇒ String
The source file name where the error occurred.
-
#warning_level ⇒ String
Warning level describes the severity and required action to suppress this warning when Firebase CLI run into it.
-
#workarounds ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Workaround>
Workarounds provide suggestions to address the compile errors or warnings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GraphqlErrorExtensions
constructor
A new instance of GraphqlErrorExtensions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GraphqlErrorExtensions
Returns a new instance of GraphqlErrorExtensions.
656 657 658 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 656 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Maps to canonical gRPC codes. If not specified, it represents Code.INTERNAL.
Corresponds to the JSON property code
626 627 628 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 626 def code @code end |
#debug_details ⇒ String
More detailed error message to assist debugging. It contains application
business logic that are inappropriate to leak publicly. In the emulator, SQL
Connect API always includes it to assist local development and debugging. In
the backend, ConnectorService always hides it. GraphqlService without
impersonation always include it. GraphqlService with impersonation includes it
only if explicitly opted-in with include_debug_details in
GraphqlRequestExtensions.
Corresponds to the JSON property debugDetails
637 638 639 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 637 def debug_details @debug_details end |
#file ⇒ String
The source file name where the error occurred. Included only for UpdateSchema
and UpdateConnector, it corresponds to File.path of the provided Source.
Corresponds to the JSON property file
643 644 645 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 643 def file @file end |
#warning_level ⇒ String
Warning level describes the severity and required action to suppress this
warning when Firebase CLI run into it.
Corresponds to the JSON property warningLevel
649 650 651 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 649 def warning_level @warning_level end |
#workarounds ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Workaround>
Workarounds provide suggestions to address the compile errors or warnings.
Corresponds to the JSON property workarounds
654 655 656 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 654 def workarounds @workarounds end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
661 662 663 664 665 666 667 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 661 def update!(**args) @code = args[:code] if args.key?(:code) @debug_details = args[:debug_details] if args.key?(:debug_details) @file = args[:file] if args.key?(:file) @warning_level = args[:warning_level] if args.key?(:warning_level) @workarounds = args[:workarounds] if args.key?(:workarounds) end |