Class: Google::Apis::FirebasedataconnectV1beta::ListSchemasResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

Message for response to listing Schemas. By default, schemas.source will not be included in the response. To specify the fields included in the response, the response field mask can be provided by using the query parameter $fields or the header X-Goog-FieldMask.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSchemasResponse

Returns a new instance of ListSchemasResponse.



1004
1005
1006
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


992
993
994
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 992

def next_page_token
  @next_page_token
end

#schemasArray<Google::Apis::FirebasedataconnectV1beta::Schema>

The list of Schemas. Corresponds to the JSON property schemas



997
998
999
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 997

def schemas
  @schemas
end

#unreachableArray<String>

Locations that could not be reached. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


1002
1003
1004
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1002

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1009
1010
1011
1012
1013
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1009

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @schemas = args[:schemas] if args.key?(:schemas)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end