Class: Google::Apis::FirebasedataconnectV1beta::Workaround

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

Workaround provides suggestions to address errors and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workaround

Returns a new instance of Workaround.



1618
1619
1620
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1618

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this workaround. Corresponds to the JSON property description

Returns:

  • (String)


1606
1607
1608
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1606

def description
  @description
end

#reasonString

Why would this workaround address the error and warning. Corresponds to the JSON property reason

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1611

def reason
  @reason
end

#replaceString

A suggested code snippet to fix the error and warning. Corresponds to the JSON property replace

Returns:

  • (String)


1616
1617
1618
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1616

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1623
1624
1625
1626
1627
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1623

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
  @replace = args[:replace] if args.key?(:replace)
end