Class: Google::Apis::FirebasedataconnectV1beta::GraphqlErrorExtensions

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

GraphqlErrorExtensions contains additional information of GraphqlError.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GraphqlErrorExtensions

Returns a new instance of GraphqlErrorExtensions.



650
651
652
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 650

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Maps to canonical gRPC codes. If not specified, it represents Code.INTERNAL. Corresponds to the JSON property code

Returns:

  • (String)


620
621
622
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 620

def code
  @code
end

#debug_detailsString

More detailed error message to assist debugging. It contains application business logic that are inappropriate to leak publicly. In the emulator, SQL Connect API always includes it to assist local development and debugging. In the backend, ConnectorService always hides it. GraphqlService without impersonation always include it. GraphqlService with impersonation includes it only if explicitly opted-in with include_debug_details in GraphqlRequestExtensions. Corresponds to the JSON property debugDetails

Returns:

  • (String)


631
632
633
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 631

def debug_details
  @debug_details
end

#fileString

The source file name where the error occurred. Included only for UpdateSchema and UpdateConnector, it corresponds to File.path of the provided Source. Corresponds to the JSON property file

Returns:

  • (String)


637
638
639
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 637

def file
  @file
end

#warning_levelString

Warning level describes the severity and required action to suppress this warning when Firebase CLI run into it. Corresponds to the JSON property warningLevel

Returns:

  • (String)


643
644
645
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 643

def warning_level
  @warning_level
end

#workaroundsArray<Google::Apis::FirebasedataconnectV1beta::Workaround>

Workarounds provide suggestions to address the compile errors or warnings. Corresponds to the JSON property workarounds



648
649
650
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 648

def workarounds
  @workarounds
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



655
656
657
658
659
660
661
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 655

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @debug_details = args[:debug_details] if args.key?(:debug_details)
  @file = args[:file] if args.key?(:file)
  @warning_level = args[:warning_level] if args.key?(:warning_level)
  @workarounds = args[:workarounds] if args.key?(:workarounds)
end