Class: Google::Apis::FirebasedataconnectV1beta::Service
- Inherits:
-
Object
- Object
- Google::Apis::FirebasedataconnectV1beta::Service
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb
Overview
A Firebase SQL Connect service.
Instance Attribute Summary collapse
-
#annotations ⇒ Hash<String,String>
Optional.
-
#connectors ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Connector>
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#reconciling ⇒ Boolean
(also: #reconciling?)
Output only.
-
#schemas ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Schema>
Output only.
-
#source ⇒ Google::Apis::FirebasedataconnectV1beta::Source
Used to represent a set of source files.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Service
constructor
A new instance of Service.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Service
Returns a new instance of Service.
1476 1477 1478 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1476 def initialize(**args) update!(**args) end |
Instance Attribute Details
#annotations ⇒ Hash<String,String>
Optional. Stores small amounts of arbitrary data.
Corresponds to the JSON property annotations
1410 1411 1412 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1410 def annotations @annotations end |
#connectors ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Connector>
Output only. The list of connectors in this service.
Corresponds to the JSON property connectors
1415 1416 1417 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1415 def connectors @connectors end |
#create_time ⇒ String
Output only. [Output only] Create time stamp.
Corresponds to the JSON property createTime
1420 1421 1422 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1420 def create_time @create_time end |
#display_name ⇒ String
Optional. Mutable human-readable name. 63 character limit.
Corresponds to the JSON property displayName
1425 1426 1427 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1425 def display_name @display_name end |
#etag ⇒ String
Output only. This checksum is computed by the server based on the value of
other fields, and may be sent on update and delete requests to ensure the
client has an up-to-date value before proceeding. AIP-154
Corresponds to the JSON property etag
1433 1434 1435 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1433 def etag @etag end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
1438 1439 1440 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1438 def labels @labels end |
#name ⇒ String
Identifier. The relative resource name of the Firebase SQL Connect service, in
the format: projects/`project`/locations/`location`/services/`service`
Note that the service ID is specific to Firebase SQL Connect and does not
correspond to any of the instance IDs of the underlying data source
connections.
Corresponds to the JSON property name
1447 1448 1449 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1447 def name @name end |
#reconciling ⇒ Boolean Also known as: reconciling?
Output only. A field that if true, indicates that the system is working update
the service.
Corresponds to the JSON property reconciling
1453 1454 1455 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1453 def reconciling @reconciling end |
#schemas ⇒ Array<Google::Apis::FirebasedataconnectV1beta::Schema>
Output only. The list of schemas in this service.
Corresponds to the JSON property schemas
1459 1460 1461 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1459 def schemas @schemas end |
#source ⇒ Google::Apis::FirebasedataconnectV1beta::Source
Used to represent a set of source files.
Corresponds to the JSON property source
1464 1465 1466 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1464 def source @source end |
#uid ⇒ String
Output only. System-assigned, unique identifier.
Corresponds to the JSON property uid
1469 1470 1471 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1469 def uid @uid end |
#update_time ⇒ String
Output only. [Output only] Update time stamp.
Corresponds to the JSON property updateTime
1474 1475 1476 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1474 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1481 1482 1483 1484 1485 1486 1487 1488 1489 1490 1491 1492 1493 1494 |
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1481 def update!(**args) @annotations = args[:annotations] if args.key?(:annotations) @connectors = args[:connectors] if args.key?(:connectors) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @reconciling = args[:reconciling] if args.key?(:reconciling) @schemas = args[:schemas] if args.key?(:schemas) @source = args[:source] if args.key?(:source) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |