Class: Google::Apis::FirebasedataconnectV1beta::Service

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

A Firebase SQL Connect service.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



1455
1456
1457
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1455

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#annotationsHash<String,String>

Optional. Stores small amounts of arbitrary data. Corresponds to the JSON property annotations

Returns:

  • (Hash<String,String>)


1404
1405
1406
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1404

def annotations
  @annotations
end

#create_timeString

Output only. [Output only] Create time stamp. Corresponds to the JSON property createTime

Returns:

  • (String)


1409
1410
1411
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1409

def create_time
  @create_time
end

#display_nameString

Optional. Mutable human-readable name. 63 character limit. Corresponds to the JSON property displayName

Returns:

  • (String)


1414
1415
1416
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1414

def display_name
  @display_name
end

#etagString

Output only. This checksum is computed by the server based on the value of other fields, and may be sent on update and delete requests to ensure the client has an up-to-date value before proceeding. AIP-154 Corresponds to the JSON property etag

Returns:

  • (String)


1422
1423
1424
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1422

def etag
  @etag
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1427
1428
1429
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1427

def labels
  @labels
end

#nameString

Identifier. The relative resource name of the Firebase SQL Connect service, in the format: projects/`project`/locations/`location`/services/`service` Note that the service ID is specific to Firebase SQL Connect and does not correspond to any of the instance IDs of the underlying data source connections. Corresponds to the JSON property name

Returns:

  • (String)


1436
1437
1438
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1436

def name
  @name
end

#reconcilingBoolean Also known as: reconciling?

Output only. A field that if true, indicates that the system is working update the service. Corresponds to the JSON property reconciling

Returns:

  • (Boolean)


1442
1443
1444
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1442

def reconciling
  @reconciling
end

#uidString

Output only. System-assigned, unique identifier. Corresponds to the JSON property uid

Returns:

  • (String)


1448
1449
1450
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1448

def uid
  @uid
end

#update_timeString

Output only. [Output only] Update time stamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


1453
1454
1455
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1453

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1460
1461
1462
1463
1464
1465
1466
1467
1468
1469
1470
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1460

def update!(**args)
  @annotations = args[:annotations] if args.key?(:annotations)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @etag = args[:etag] if args.key?(:etag)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @reconciling = args[:reconciling] if args.key?(:reconciling)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end