Class: Google::Apis::FirebasedataconnectV1beta::Workaround

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

Workaround provides suggestions to address errors and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workaround

Returns a new instance of Workaround.



1600
1601
1602
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1600

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this workaround. Corresponds to the JSON property description

Returns:

  • (String)


1588
1589
1590
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1588

def description
  @description
end

#reasonString

Why would this workaround address the error and warning. Corresponds to the JSON property reason

Returns:

  • (String)


1593
1594
1595
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1593

def reason
  @reason
end

#replaceString

A suggested code snippet to fix the error and warning. Corresponds to the JSON property replace

Returns:

  • (String)


1598
1599
1600
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1598

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1605
1606
1607
1608
1609
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1605

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
  @replace = args[:replace] if args.key?(:replace)
end