Class: Google::Apis::FirebasedataconnectV1beta::Workaround

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/firebasedataconnect_v1beta/classes.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb,
lib/google/apis/firebasedataconnect_v1beta/representations.rb

Overview

Workaround provides suggestions to address errors and warnings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Workaround

Returns a new instance of Workaround.



1594
1595
1596
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1594

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Description of this workaround. Corresponds to the JSON property description

Returns:

  • (String)


1582
1583
1584
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1582

def description
  @description
end

#reasonString

Why would this workaround address the error and warning. Corresponds to the JSON property reason

Returns:

  • (String)


1587
1588
1589
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1587

def reason
  @reason
end

#replaceString

A suggested code snippet to fix the error and warning. Corresponds to the JSON property replace

Returns:

  • (String)


1592
1593
1594
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1592

def replace
  @replace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1599
1600
1601
1602
1603
# File 'lib/google/apis/firebasedataconnect_v1beta/classes.rb', line 1599

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @reason = args[:reason] if args.key?(:reason)
  @replace = args[:replace] if args.key?(:replace)
end